==> dmrgpp_6.02.orig-psimaglite.tar.gz: PsimagLite-3.02/src/Parallelizer.h <==
/*
Copyright (c) 2009-2017, UT-Battelle, LLC
All rights reserved

[PsimagLite, Version 1.]
[by G.A., Oak Ridge National Laboratory]

UT Battelle Open Source Software License 11242008

OPEN SOURCE LICENSE

Subject to the conditions of this License, each
contributor to this software hereby grants, free of
charge, to any person obtaining a copy of this software
and associated documentation files (the "Software"), a
perpetual, worldwide, non-exclusive, no-charge,
royalty-free, irrevocable copyright license to use, copy,
modify, merge, publish, distribute, and/or sublicense
copies of the Software.

1. Redistributions of Software must retain the above
copyright and license notices, this list of conditions,
and the following disclaimer.  Changes or modifications
to, or derivative works of, the Software should be noted
with comments and the contributor and organization's
name.

2. Neither the names of UT-Battelle, LLC or the
Department of Energy nor the names of the Software
contributors may be used to endorse or promote products
derived from this software without specific prior written
permission of UT-Battelle.

3. The software and the end-user documentation included
with the redistribution, with or without modification,
must include the following acknowledgment:

"This product includes software produced by UT-Battelle,
LLC under Contract No. DE-AC05-00OR22725  with the
Department of Energy."

-----------------------------------------------------------
DISCLAIMER

THE SOFTWARE IS SUPPLIED BY THE COPYRIGHT HOLDERS AND
CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
COPYRIGHT OWNER, CONTRIBUTORS, UNITED STATES GOVERNMENT,
OR THE UNITED STATES DEPARTMENT OF ENERGY BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
DAMAGE.

NEITHER THE UNITED STATES GOVERNMENT, NOR THE UNITED
STATES DEPARTMENT OF ENERGY, NOR THE COPYRIGHT OWNER, NOR
ANY OF THEIR EMPLOYEES, REPRESENTS THAT THE USE OF ANY
INFORMATION, DATA, APPARATUS, PRODUCT, OR PROCESS
DISCLOSED WOULD NOT INFRINGE PRIVATELY OWNED RIGHTS.

-----------------------------------------------------------

*/
/** \ingroup PsimagLite */
/*@{*/

/*! \file Parallelizer.h
 *
 */
#ifndef PARALLELIZER_H
#define PARALLELIZER_H
#include <stdexcept>
#include "Vector.h"
#include "Concurrency.h"
#include "CodeSectionParams.h"
#include "Map.h"

#define ActualPthreadsName PthreadsNg
#define ActualPthreadsN() "PthreadsNg.h"
#define ActualNoPthreadsName NoPthreadsNg
#define ActualNoPthreadsN() "NoPthreadsNg.h"

#ifdef USE_PTHREADS

#include ActualPthreadsN()

#else

#include ActualNoPthreadsN()

#endif // USE_PTHREADS

namespace PsimagLite {
template<typename InstanceType, typename LoadBalancerType=LoadBalancerDefault>
class Parallelizer

#ifdef USE_PTHREADS

        : public ActualPthreadsName<InstanceType, LoadBalancerType> {
	typedef ActualPthreadsName<InstanceType, LoadBalancerType> BaseType;

#else
        : public ActualNoPthreadsName<InstanceType, LoadBalancerType>  {
	typedef ActualNoPthreadsName<InstanceType, LoadBalancerType> BaseType;
#endif

public:

	Parallelizer(const CodeSectionParams& cs)
	    : BaseType(cs)
	{}

	Parallelizer(String codeSectionParams)
	    : BaseType(codeSectionParamss_[codeSectionParams])
	{}

	static bool exists(String name)
	{
		return (codeSectionParamss_.find(name) != codeSectionParamss_.end());
	}

	static void push(String name, const CodeSectionParams& cs)
	{
		codeSectionParamss_[name] = cs;
	}

	static void clear() { codeSectionParamss_.clear(); }

private:

	static Map<String, CodeSectionParams>::Type codeSectionParamss_;
};
} // namespace PsimagLite 

/*@}*/	
#endif

==> dmrgpp_6.06.orig-psimaglite.tar.gz: PsimagLite-3.06/src/Parallelizer.h <==
/*
Copyright (c) 2009-2017, UT-Battelle, LLC
All rights reserved

[PsimagLite, Version 1.]
[by G.A., Oak Ridge National Laboratory]

UT Battelle Open Source Software License 11242008

OPEN SOURCE LICENSE

Subject to the conditions of this License, each
contributor to this software hereby grants, free of
charge, to any person obtaining a copy of this software
and associated documentation files (the "Software"), a
perpetual, worldwide, non-exclusive, no-charge,
royalty-free, irrevocable copyright license to use, copy,
modify, merge, publish, distribute, and/or sublicense
copies of the Software.

1. Redistributions of Software must retain the above
copyright and license notices, this list of conditions,
and the following disclaimer.  Changes or modifications
to, or derivative works of, the Software should be noted
with comments and the contributor and organization's
name.

2. Neither the names of UT-Battelle, LLC or the
Department of Energy nor the names of the Software
contributors may be used to endorse or promote products
derived from this software without specific prior written
permission of UT-Battelle.

3. The software and the end-user documentation included
with the redistribution, with or without modification,
must include the following acknowledgment:

"This product includes software produced by UT-Battelle,
LLC under Contract No. DE-AC05-00OR22725  with the
Department of Energy."

-----------------------------------------------------------
DISCLAIMER

THE SOFTWARE IS SUPPLIED BY THE COPYRIGHT HOLDERS AND
CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
COPYRIGHT OWNER, CONTRIBUTORS, UNITED STATES GOVERNMENT,
OR THE UNITED STATES DEPARTMENT OF ENERGY BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
DAMAGE.

NEITHER THE UNITED STATES GOVERNMENT, NOR THE UNITED
STATES DEPARTMENT OF ENERGY, NOR THE COPYRIGHT OWNER, NOR
ANY OF THEIR EMPLOYEES, REPRESENTS THAT THE USE OF ANY
INFORMATION, DATA, APPARATUS, PRODUCT, OR PROCESS
DISCLOSED WOULD NOT INFRINGE PRIVATELY OWNED RIGHTS.

-----------------------------------------------------------

*/
/** \ingroup PsimagLite */
/*@{*/

/*! \file Parallelizer.h
 *
 */
#ifndef PARALLELIZER_H
#define PARALLELIZER_H
#include "CodeSectionParams.h"
#include "Concurrency.h"
#include "Map.h"
#include "Vector.h"
#include <stdexcept>

#define ActualPthreadsName PthreadsNg
#define ActualPthreadsN() "PthreadsNg.h"
#define ActualNoPthreadsName NoPthreadsNg
#define ActualNoPthreadsN() "NoPthreadsNg.h"

#ifdef USE_PTHREADS

#include ActualPthreadsN()

#else

#include ActualNoPthreadsN()

#endif // USE_PTHREADS

namespace PsimagLite
{
template <typename InstanceType,
    typename LoadBalancerType = LoadBalancerDefault>
class Parallelizer

#ifdef USE_PTHREADS

    : public ActualPthreadsName<InstanceType, LoadBalancerType>
{
	typedef ActualPthreadsName<InstanceType, LoadBalancerType> BaseType;

#else
    : public ActualNoPthreadsName<InstanceType, LoadBalancerType>
{
	typedef ActualNoPthreadsName<InstanceType, LoadBalancerType> BaseType;
#endif

public:

	Parallelizer(const CodeSectionParams& cs)
	    : BaseType(cs)
	{
	}

	Parallelizer(String codeSectionParams)
	    : BaseType(codeSectionParamss_[codeSectionParams])
	{
	}

	static bool exists(String name)
	{
		return (codeSectionParamss_.find(name) != codeSectionParamss_.end());
	}

	static void push(String name, const CodeSectionParams& cs)
	{
		codeSectionParamss_[name] = cs;
	}

	static void clear() { codeSectionParamss_.clear(); }

private:

	static Map<String, CodeSectionParams>::Type codeSectionParamss_;
};
} // namespace PsimagLite

/*@}*/
#endif
